@@ -14,10 +14,6 @@ from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_c
 from sedaro_base_client.apis.paths.models_branches_branch_id_system_subsystems_components_block_id import ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_ import ModelsBranchesBranchIdSystemLoads
 from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_block_id import ModelsBranchesBranchIdSystemLoadsBlockId
-from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_actuator_loads_ import ModelsBranchesBranchIdSystemLoadsActuatorLoads
-from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_actuator_loads_block_id import ModelsBranchesBranchIdSystemLoadsActuatorLoadsBlockId
-from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_temp_control_loads_ import ModelsBranchesBranchIdSystemLoadsTempControlLoads
-from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_temp_control_loads_block_id import ModelsBranchesBranchIdSystemLoadsTempControlLoadsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_states_ import ModelsBranchesBranchIdSystemLoadsStates
 from sedaro_base_client.apis.paths.models_branches_branch_id_system_loads_states_block_id import ModelsBranchesBranchIdSystemLoadsStatesBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_operational_modes_ import ModelsBranchesBranchIdCdhConopsOperationalModes
@@ -104,6 +100,8 @@ from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbi
 from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_orbit_determination_gps_block_id import ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_sliding_mode_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode
 from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_sliding_mode_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_pid_ import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid
+from sedaro_base_client.apis.paths.models_branches_branch_id_gnc_algorithms_attitude_control_pid_block_id import ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_agents_ import ModelsBranchesBranchIdAgents
 from sedaro_base_client.apis.paths.models_branches_branch_id_agents_block_id import ModelsBranchesBranchIdAgentsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_clock_configs_ import ModelsBranchesBranchIdClockConfigs
@@ -136,10 +134,6 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_: ModelsBranchesBranchIdSystemLoads,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_: ModelsBranchesBranchIdSystemLoadsActuatorLoads,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsActuatorLoadsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_: ModelsBranchesBranchIdSystemLoadsTempControlLoads,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsTempControlLoadsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_: ModelsBranchesBranchIdSystemLoadsStates,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsStatesBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_: ModelsBranchesBranchIdCdhConopsOperationalModes,
@@ -226,6 +220,8 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode,
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_: ModelsBranchesBranchIdAgents,
         PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_BLOCK_ID: ModelsBranchesBranchIdAgentsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_: ModelsBranchesBranchIdClockConfigs,
@@ -259,10 +255,6 @@ path_to_api = PathToApi(
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_BLOCK_ID: ModelsBranchesBranchIdSystemSubsystemsComponentsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_: ModelsBranchesBranchIdSystemLoads,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_: ModelsBranchesBranchIdSystemLoadsActuatorLoads,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsActuatorLoadsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_: ModelsBranchesBranchIdSystemLoadsTempControlLoads,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsTempControlLoadsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_: ModelsBranchesBranchIdSystemLoadsStates,
         PathValues.MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_BLOCK_ID: ModelsBranchesBranchIdSystemLoadsStatesBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_: ModelsBranchesBranchIdCdhConopsOperationalModes,
@@ -349,6 +341,8 @@ path_to_api = PathToApi(
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsOrbitDeterminationGpsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingMode,
         PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlSlidingModeBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPid,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_BLOCK_ID: ModelsBranchesBranchIdGncAlgorithmsAttitudeControlPidBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_: ModelsBranchesBranchIdAgents,
         PathValues.MODELS_BRANCHES_BRANCH_ID_AGENTS_BLOCK_ID: ModelsBranchesBranchIdAgentsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_: ModelsBranchesBranchIdClockConfigs,
