@@ -19,10 +19,6 @@ class PathValues(str, enum.Enum):
     MODELS_BRANCHES_BRANCH_ID_SYSTEM_SUBSYSTEMS_COMPONENTS_BLOCK_ID = "/models/branches/{branchId}/system/subsystems/components/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ = "/models/branches/{branchId}/system/loads/"
     MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_BLOCK_ID = "/models/branches/{branchId}/system/loads/{blockId}"
-    MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_ = "/models/branches/{branchId}/system/loads/actuator-loads/"
-    MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_ACTUATORLOADS_BLOCK_ID = "/models/branches/{branchId}/system/loads/actuator-loads/{blockId}"
-    MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_ = "/models/branches/{branchId}/system/loads/temp-control-loads/"
-    MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_TEMPCONTROLLOADS_BLOCK_ID = "/models/branches/{branchId}/system/loads/temp-control-loads/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_ = "/models/branches/{branchId}/system/loads/states/"
     MODELS_BRANCHES_BRANCH_ID_SYSTEM_LOADS_STATES_BLOCK_ID = "/models/branches/{branchId}/system/loads/states/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_OPERATIONALMODES_ = "/models/branches/{branchId}/cdh/conops/operational-modes/"
@@ -109,6 +105,8 @@ class PathValues(str, enum.Enum):
     MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ORBITDETERMINATION_GPS_BLOCK_ID = "/models/branches/{branchId}/gnc/algorithms/orbit-determination/gps/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_ = "/models/branches/{branchId}/gnc/algorithms/attitude-control/sliding-mode/"
     MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_SLIDINGMODE_BLOCK_ID = "/models/branches/{branchId}/gnc/algorithms/attitude-control/sliding-mode/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_ = "/models/branches/{branchId}/gnc/algorithms/attitude-control/pid/"
+    MODELS_BRANCHES_BRANCH_ID_GNC_ALGORITHMS_ATTITUDECONTROL_PID_BLOCK_ID = "/models/branches/{branchId}/gnc/algorithms/attitude-control/pid/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_AGENTS_ = "/models/branches/{branchId}/agents/"
     MODELS_BRANCHES_BRANCH_ID_AGENTS_BLOCK_ID = "/models/branches/{branchId}/agents/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_CLOCKCONFIGS_ = "/models/branches/{branchId}/clock-configs/"
